@@ -13,7 +13,7 @@ use HTML::Scrubber     ();
 use Lingua::JA::Regular::Unicode ();
 use Lingua::JA::Dakuon ();
 
-our $VERSION   = '0.20';
+our $VERSION   = '0.21';
 our @EXPORT    = qw();
 our @EXPORT_OK = qw(nfkc nfkd nfc nfd decode_entities strip_html
 alnum_z2h alnum_h2z space_z2h space_h2z katakana_z2h katakana_h2z
@@ -230,15 +230,23 @@ the elements of @options.
 External functions are also addable.
 (See dearinsu_to_desu function of the SYNOPSIS section.)
 
-=head3 dashes2long
+
+=head2 normalize($text)
+
+normalizes $text.
+
+
+=head1 OPTIONS
+
+=head2 dashes2long
 
 Note that this option does not convert hyphens into long.
 
-=head3 unify_long_spaces
+=head2 unify_long_spaces
 
 Note that this option unifies only SPACE(U+0020) and IDEOGRAPHIC SPACE(U+3000).
 
-=head3 remove_controls
+=head2 remove_controls
 
 Note that this option does not remove the following chars:
 
@@ -247,9 +255,9 @@ Note that this option does not remove the following chars:
   CARRIAGE RETURN
 
 
-=head3 unify_whitespaces
+=head2 unify_whitespaces
 
-This option converts following chars into SPACE(U+0020).
+This option converts the following chars into SPACE(U+0020).
 
   LINE TABULATION
   FORM FEED
@@ -273,16 +281,13 @@ This option converts following chars into SPACE(U+0020).
   NARROW NO-BREAK SPACE
   MEDIUM MATHEMATICAL SPACE
 
-Note that this does not convert following chars:
+Note that this does not convert the following chars:
 
   CHARACTER TABULATION
   LINE FEED
   CARRIAGE RETURN
   IDEOGRAPHIC SPACE
 
-=head2 normalize($text)
-
-normalizes $text.
 
 =head1 AUTHOR
 
